/* --COPYRIGHT--,BSD
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//#############################################################################
//
//! \file   board.c
//!
//! \brief  This is the board file for the BSL keypad
//

//*****************************************************************************
// Includes
//*****************************************************************************

#include "board.h"
#include "config.h"

//*****************************************************************************
// Function Implementations
//*****************************************************************************
#define USE_CAPTIVATE_CENTER 0

void Board_init(void)
{
    uint8_t ui8LFOsc = DEFAULT_OSC_SELECTION;

    // P1.0: OUTPUT LOW
    // P1.1: IRQ (OPEN DRAIN)
    // P1.2: UCB0 I2C SDA
    // P1.3: UCB0 I2C SCL
    // P1.4: UCA0 UART TXD
    // P1.5: UCA0 UART RXD
    // P1.6: LED2
    // P1.7: LED1

#if USE_CAPTIVATE_CENTER
    P1OUT  = (0);
    P1DIR  = (GPIO_PIN0 | GPIO_PIN1 | GPIO_PIN6 | GPIO_PIN7);
    P1SEL0 = (GPIO_PIN2 | GPIO_PIN3 | GPIO_PIN4 | GPIO_PIN5);
    P1SEL1 = (0);
#else
    P1OUT  = (0);
    P1DIR  = (GPIO_PIN0 | GPIO_PIN1 | GPIO_PIN4 | GPIO_PIN5 | GPIO_PIN6 | GPIO_PIN7);
    P1SEL0 = (GPIO_PIN2 | GPIO_PIN3);
    P1SEL1 = (0);
#endif

    P2OUT  =  (0);
    P2DIR  =  (GPIO_PIN0 | GPIO_PIN1);
    P2SEL0 =  (0);
    P2SEL1 =  (0);

    P3OUT  =  (0);
    P3DIR  =  (GPIO_PIN5 | GPIO_PIN2 | GPIO_PIN6);
    P3SEL0 =  (0);
    P3SEL1 =  (0);

    //
    // Clear port lock
    //
    PM5CTL0 &= ~LOCKLPM5;
	
	// Configure FRAM wait state (set to 1 to support 16MHz MCLK)
#if !defined(CONFIG_ENABLE_PRINTF_SUPPORT) || (CONFIG_ENABLE_PRINTF_SUPPORT == 0)
	FRAMCtl_configureWaitStateControl(FRAMCTL_ACCESS_TIME_CYCLES_1);
#else
  FRAMCtl_configureWaitStateControl(FRAMCTL_ACCESS_TIME_CYCLES_0);
#endif

#if (DEFAULT_OSC_SELECTION == CS_XT1CLK_SELECT)
    //
    // Attempt to start the low frequency crystal oscillator
    //
    CS_setExternalClockSource(XT1_OSC_FREQ);
    if (CS_turnOnXT1LFWithTimeout(CS_XT1_DRIVE_0, XT1_OSC_TIMEOUT) == STATUS_FAIL)
    {
        //
        // If a crystal is not present or is failing, switch the LF
        // clock definition to the internal 32kHz reference oscillator.
        //
        ui8LFOsc = CS_REFOCLK_SELECT;
    }
#endif

    //
    // Initialize Clock Signals
    //
    CS_initClockSignal(CS_FLLREF, ui8LFOsc, CS_CLOCK_DIVIDER_1);
    CS_initClockSignal(CS_ACLK, ui8LFOsc, CS_CLOCK_DIVIDER_1);
#if !defined(CONFIG_ENABLE_PRINTF_SUPPORT) || (CONFIG_ENABLE_PRINTF_SUPPORT == 0)
    CS_initClockSignal(CS_MCLK, CS_DCOCLKDIV_SELECT, CS_CLOCK_DIVIDER_1);
    CS_initClockSignal(CS_SMCLK, CS_DCOCLKDIV_SELECT, CS_CLOCK_DIVIDER_8);
#else
    CS_initClockSignal(CS_MCLK, CS_DCOCLKDIV_SELECT, CS_CLOCK_DIVIDER_2);
    CS_initClockSignal(CS_SMCLK, CS_DCOCLKDIV_SELECT, CS_CLOCK_DIVIDER_4);
#endif

    //
    // Tune the DCO parameters
    //
    CS_initFLL((MCLK_FREQ/1000), FLL_RATIO);
    CS_clearAllOscFlagsWithTimeout(1000);
}

int _system_pre_init(void)
{
    // Disable watchdog timer before CINIT.
    WDTCTL = WDTPW | WDTHOLD;
    return 1;
}
